@@ -1,37 +1,41 @@
-# Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
+#  Pyrogram - Telegram MTProto API Client Library for Python
+#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
 #
-# This file is part of Pyrogram.
+#  This file is part of Pyrogram.
 #
-# Pyrogram is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published
-# by the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+#  Pyrogram is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU Lesser General Public License as published
+#  by the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
 #
-# Pyrogram is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
+#  Pyrogram is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public License
-# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
+#  You should have received a copy of the GNU Lesser General Public License
+#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
 from struct import pack
+from typing import List
 
 import pyrogram
 from pyrogram.api import types
-from .photo_size import PhotoSize
-from ..pyrogram_type import PyrogramType
-from ...ext.utils import encode
+from .thumbnail import Thumbnail
+from ..object import Object
+from ...ext.utils import encode_file_id, encode_file_ref
 
 
-class Video(PyrogramType):
+class Video(Object):
     """A video file.
 
     Parameters:
         file_id (``str``):
             Unique identifier for this file.
 
+        file_ref (``str``):
+            Up to date file reference.
+
         width (``int``):
             Video width as defined by sender.
 
@@ -41,9 +45,6 @@ class Video(PyrogramType):
         duration (``int``):
             Duration of the video in seconds as defined by sender.
 
-        thumb (:obj:`PhotoSize`, *optional*):
-            Video thumbnail.
-
         file_name (``str``, *optional*):
             Video file name.
 
@@ -58,46 +59,56 @@ class Video(PyrogramType):
 
         date (``int``, *optional*):
             Date the video was sent in Unix time.
-    """
 
-    __slots__ = [
-        "file_id", "width", "height", "duration", "thumb", "file_name", "mime_type", "supports_streaming", "file_size",
-        "date"
-    ]
+        ttl_seconds (``int``. *optional*):
+            Time-to-live seconds, for secret photos.
+
+        thumbs (List of :obj:`Thumbnail`, *optional*):
+            Video thumbnails.
+    """
 
     def __init__(
         self,
         *,
         client: "pyrogram.BaseClient" = None,
         file_id: str,
+        file_ref: str,
         width: int,
         height: int,
         duration: int,
-        thumb: PhotoSize = None,
         file_name: str = None,
         mime_type: str = None,
         supports_streaming: bool = None,
         file_size: int = None,
-        date: int = None
+        date: int = None,
+        ttl_seconds: int = None,
+        thumbs: List[Thumbnail] = None
     ):
         super().__init__(client)
 
         self.file_id = file_id
+        self.file_ref = file_ref
         self.width = width
         self.height = height
         self.duration = duration
-        self.thumb = thumb
         self.file_name = file_name
         self.mime_type = mime_type
         self.supports_streaming = supports_streaming
         self.file_size = file_size
         self.date = date
+        self.ttl_seconds = ttl_seconds
+        self.thumbs = thumbs
 
     @staticmethod
-    def _parse(client, video: types.Document, video_attributes: types.DocumentAttributeVideo,
-               file_name: str) -> "Video":
+    def _parse(
+        client,
+        video: types.Document,
+        video_attributes: types.DocumentAttributeVideo,
+        file_name: str,
+        ttl_seconds: int = None
+    ) -> "Video":
         return Video(
-            file_id=encode(
+            file_id=encode_file_id(
                 pack(
                     "<iiqq",
                     4,
@@ -106,14 +117,16 @@ class Video(PyrogramType):
                     video.access_hash
                 )
             ),
+            file_ref=encode_file_ref(video.file_reference),
             width=video_attributes.w,
             height=video_attributes.h,
             duration=video_attributes.duration,
-            thumb=PhotoSize._parse(client, video.thumbs),
             file_name=file_name,
             mime_type=video.mime_type,
             supports_streaming=video_attributes.supports_streaming,
             file_size=video.size,
             date=video.date,
+            ttl_seconds=ttl_seconds,
+            thumbs=Thumbnail._parse(client, video),
             client=client
         )
